@@ -150,7 +150,7 @@ bidirectional and suitable for WebSocket or other tunnel protocols.
 B<WARNING>: Once you call this method, Feersum relinquishes control of the
 socket. You are responsible for all I/O and must not use other Feersum
 response methods on this connection.  B<Do not> call C<io()> on regular
-(non-tunnel) HTTP/2 streams — it would expose the shared TCP socket
+(non-tunnel) HTTP/2 streams -- it would expose the shared TCP socket
 underlying all multiplexed streams on that connection.
 
 =item C<< $req->return_from_io($io) >>
@@ -195,7 +195,7 @@ body content length (psgi CONTENT_LENGTH)
 =item C<< my $input = $req->input >>
 
 Input body handler (psgi.input).  Returns C<undef> for requests with no body
-(e.g., GET, HEAD) — check the return value before calling C<read()>.  It is
+(e.g., GET, HEAD) -- check the return value before calling C<read()>.  It is
 advised to close it after read is done.
 
 =item C<< my $headers = $req->headers([normalization_style]) >>
